@@ -15,11 +15,12 @@ use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
 use Scalar::Util qw{ looks_like_number refaddr };
 use Test::More 0.88;
 
-our $VERSION = '0.080_01';
+our $VERSION = '0.081_01';
 
 use constant ARRAY_REF	=> ref [];
 
 our @EXPORT_OK = qw{
+    builder
     cache_count
     choose
     klass
@@ -72,6 +73,10 @@ my (
     $result,		# Operation result.
 );
 
+sub builder {
+    return Test::More->builder();
+}
+
 sub cache_count {
     my ( $expect ) = @_;
     defined $expect or $expect = 0;
@@ -520,6 +525,11 @@ objects, but rather the state of the system as a whole.
 
 The following subroutines are exported:
 
+=head2 builder
+
+This subroutine returns the underlying L<Test::Builder|Test::Builder>
+object.
+
 =head2 cache_count
 
  cache_count( 1 );
